==> haskell-crypto-random-0.0.9-57-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-2iWQJOC6skvBMAOa2t6pbc
key: crypto-random-0.0.9-2iWQJOC6skvBMAOa2t6pbc
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
abi: b4b7354b727ced1547e7272be685464c
exposed: True
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-2iWQJOC6skvBMAOa2t6pbc
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    securemem-0.1.10-1S3TO7XVNlX6rp8CclufFY unix-2.7.2.2
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             securemem-0.1.10-1S3TO7XVNlX6rp8CclufFY=cb6729a72cff77fc11f938a75457318a
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-69-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-FWjny2ACuEk74S93d3lIOm
key: crypto-random-0.0.9-FWjny2ACuEk74S93d3lIOm
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
abi: ab3b0f3d326ec2e98980f9a72390f112
exposed: True
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
import-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-FWjny2ACuEk74S93d3lIOm
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    securemem-0.1.10-47XaaCnM3DyGgdDgPxhm0Y unix-2.7.2.2
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             securemem-0.1.10-47XaaCnM3DyGgdDgPxhm0Y=cf3c2e0d30f5e4e8bb8f8e48ab3227cd
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
